@@ -17,8 +17,11 @@
  */
 
 #include <stdio.h>
-#include <ncurses.h>
-#include <menu.h>
+
+#include <ncursesw/ncurses.h>
+#include <ncursesw/menu.h>
+#include <ncursesw/form.h>
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -159,9 +162,9 @@ int add_to_dic()
 	strcpy(cdname, "\0");
 	strcpy(cd_num, "\0");
 	strcpy(category, "none\0");
-	if (input_volume(_("CD name"), _("Enter CD name:"), cdname)==1) {
-	    if (input_volume(_("CD Number"), _("Number of disk:"), cd_num)==1){
-		if (input_volume(_("Category"), _("Enter category:"), category)==1){
+	if (input_box(_("CD name"), _("Enter CD name:"), cdname, 0) == 1) {
+	    if (input_box(_("CD Number"), _("Number of disk:"), cd_num, 0) == 1){
+		if (input_box(_("Category"), _("Enter category:"), category, 0) == 1){
 		    sprintf(cmd, "mount %s", config.cdrwdevice);
 		    run_command(cmd, _("Mounting cdrom..."), 0, 0, 0, "");
 		    insert_disk(cdname, cd_num, category);
@@ -905,7 +908,7 @@ int load_disk(char *type, char *diskname, char* dir)
 		    file_list[c].cd_name=(char *)malloc(strlen(row[1])+1);
 		    sprintf(file_list[c].cd_name, "%s", row[1]);
 		    sprintf(line, "%s", row[2]);
-		    (char *)linestr=strtok((char *)line, (char *)"/");
+		    linestr=strtok((char *)line, (char *)"/");
 		    if (dir_level>2)
 			for (i=1; i<=(dir_level-2); i++){
 			    linestr=strtok(NULL, "/");
@@ -1435,7 +1438,7 @@ int search_in_dic()
     char *line, itemname[100];
     char *linestr;
 
-    if (input_volume(_("Search in content"), _("Enter query string:"), file)==1) {
+    if (input_box(_("Search in content"), _("Enter query string:"), file, 0) == 1) {
 	if (file[0]=='\0'){
 	   search==0;
 	   werase(cddbwin.info);
