@@ -22,7 +22,7 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <ncurses.h>
+#include <ncursesw/ncurses.h>
 #include <string.h>
 #include <dirent.h>
 #include <libintl.h>
