@@ -28,7 +28,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <dirent.h>
-#include <ncurses.h>
+#include <ncursesw/ncurses.h>
 #include <regex.h>
 #include <pthread.h>
 #include <nl_types.h>
