@@ -20,9 +20,12 @@
 #include <string.h>
 #include <unistd.h>
 #include <ctype.h>
-#include <ncurses.h>
+
+#include <ncursesw/ncurses.h>
+#include <ncursesw/menu.h>
+#include <ncursesw/form.h>
+
 #include <nl_types.h>
-#include <form.h>
 #include <libintl.h>
 #include "options.h"
 #include "config.h"
@@ -621,7 +624,7 @@ static int page_one()
 	    case KEY_DC:
 		form_driver(form_page[0], REQ_DEL_CHAR);
 		break;
-	    case KEY_F(2):
+	    // case KEY_F(2): not in this release
 	    case KEY_F(10):
 		// return main loop
 		form_driver(form_page[0], REQ_VALIDATION);
@@ -976,7 +979,7 @@ static int page_two()
     return ch;
 }
 
-void options_window()
+void options_window(void)
 {
     char *in;
     int ch, i, page=1;
@@ -1001,12 +1004,14 @@ void options_window()
 		    ch=page_one();
 		}
 		break;
+#if 0 // not in this release
 	    case KEY_F(2):
 		if ( page!=2 ) {
 		    page=2;
 		    ch=page_two();
 		}
 		break;
+#endif
 	    case KEY_F(10):
 		write_conf(config);
 		delwin(optwin.main);
