@@ -40,9 +40,10 @@ struct conf {
     char bootimg[256];
 };
 
-struct conf read_conf();
+struct conf read_conf(void);
 int inbox(WINDOW *input, char *init);
 void write_conf(struct conf config);
 void put_ckbox(WINDOW *win, int y, int x);
+void options_window(void);
 
 #endif
